==> xmapcore_1.2.8.tar.gz: xmapcore/man/xmapcore.to.Rd <==
\name{xmapcore.to}
\alias{xmapcore.to}
\alias{array.to.probeset}
\alias{domain.to.gene}
\alias{domain.to.probeset}
\alias{domain.to.protein}
\alias{domain.to.transcript}
\alias{est_exon.to.est_gene}
\alias{est_exon.to.est_transcript}
\alias{est_exon.to.probeset}
\alias{est_gene.to.est_exon}
\alias{est_gene.to.est_transcript}
\alias{est_gene.to.probeset}
\alias{est_transcript.to.est_exon}
\alias{est_transcript.to.est_gene}
\alias{est_transcript.to.probeset}
\alias{exon.to.gene}
\alias{exon.to.probeset}
\alias{exon.to.transcript}
\alias{gene.to.domain}
\alias{gene.to.exon}
\alias{gene.to.exon_probeset}
\alias{gene.to.probeset}
\alias{gene.to.protein}
\alias{gene.to.symbol}
\alias{gene.to.synonym}
\alias{gene.to.transcript}
\alias{prediction_transcript.to.prediction_exon}
\alias{prediction_transcript.to.probeset}
\alias{probe.to.hit}
\alias{probe.to.probeset}
\alias{probeset.to.cdnatranscript}
\alias{probeset.to.domain}
\alias{probeset.to.est_exon}
\alias{probeset.to.est_gene}
\alias{probeset.to.est_transcript}
\alias{probeset.to.exon}
\alias{probeset.to.gene}
\alias{probeset.to.hit}
\alias{probeset.to.prediction_transcript}
\alias{probeset.to.probe}
\alias{probeset.to.protein}
\alias{probeset.to.transcript}
\alias{protein.to.domain}
\alias{protein.to.gene}
\alias{protein.to.probeset}
\alias{protein.to.transcript}
\alias{symbol.to.est_gene}
\alias{symbol.to.est_transcript}
\alias{symbol.to.gene}
\alias{symbol.to.transcript}
\alias{synonym.to.est_gene}
\alias{synonym.to.est_transcript}
\alias{synonym.to.gene}
\alias{synonym.to.transcript}
\alias{transcript.to.cdnaprobeset}
\alias{transcript.to.domain}
\alias{transcript.to.exon}
\alias{transcript.to.exon_probeset}
\alias{transcript.to.gene}
\alias{transcript.to.probeset}
\alias{transcript.to.protein}
\alias{transcript.to.synonym}
\title{
  xmapcore \'to\' functions
}
\description{
  Map between the different levels of annotation in X:Map. For example, given a vector of gene identifiers, \code{gene.to.exon} 
  will return the exons in those genes.
}
\usage{
  array.to.probeset( ids, as.vector=TRUE )
  domain.to.gene( ids, as.vector=TRUE )
  domain.to.probeset( ids, as.vector=TRUE )
  domain.to.protein( ids, as.vector=TRUE )
  domain.to.transcript( ids, as.vector=TRUE )
  est_exon.to.est_gene( ids, as.vector=TRUE )
  est_exon.to.est_transcript( ids, as.vector=TRUE )
  est_exon.to.probeset( ids, as.vector=TRUE )
  est_gene.to.est_exon( ids, as.vector=TRUE )
  est_gene.to.est_transcript( ids, as.vector=TRUE )
  est_gene.to.probeset( ids, as.vector=TRUE )
  est_transcript.to.est_exon( ids, as.vector=TRUE )
  est_transcript.to.est_gene( ids, as.vector=TRUE )
  est_transcript.to.probeset( ids, as.vector=TRUE )
  exon.to.gene( ids, as.vector=TRUE )
  exon.to.probeset( ids, as.vector=TRUE )
  exon.to.transcript( ids, as.vector=TRUE )
  gene.to.domain( ids, as.vector=TRUE )
  gene.to.exon( ids, as.vector=TRUE )
  gene.to.exon_probeset( ids, probes.min=4 )
  gene.to.probeset( ids, as.vector=TRUE )
  gene.to.protein( ids, as.vector=TRUE )
  gene.to.symbol( ids )
  gene.to.synonym( ids, as.vector=TRUE )
  gene.to.transcript( ids, as.vector=TRUE )
  prediction_transcript.to.prediction_exon( ids )
  prediction_transcript.to.probeset( ids, as.vector=TRUE )
  probe.to.hit( ids )
  probe.to.probeset( ids, as.vector=TRUE )
  probeset.to.cdnatranscript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.domain( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.est_exon( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.est_gene( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.est_transcript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.exon( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.gene( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.hit( ids, rm.unreliable=TRUE )
  probeset.to.prediction_transcript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.probe( ids, as.vector=TRUE )
  probeset.to.protein( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.transcript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  protein.to.domain( ids, as.vector=TRUE )
  protein.to.gene( ids, as.vector=TRUE )
  protein.to.probeset( ids, as.vector=TRUE )
  protein.to.transcript( ids, as.vector=TRUE )
  symbol.to.est_gene( ids, as.vector=TRUE )
  symbol.to.est_transcript( ids, as.vector=TRUE )
  symbol.to.gene( ids, as.vector=TRUE )
  symbol.to.transcript( ids, as.vector=TRUE )
  synonym.to.est_gene( ids, as.vector=TRUE )
  synonym.to.est_transcript( ids, as.vector=TRUE )
  synonym.to.gene( ids, as.vector=TRUE )
  synonym.to.transcript( ids, as.vector=TRUE )
  transcript.to.cdnaprobeset( ids, as.vector=TRUE )
  transcript.to.domain( ids, as.vector=TRUE )
  transcript.to.exon( ids, as.vector=TRUE )
  transcript.to.exon_probeset( ids, probes.min=4 )
  transcript.to.gene( ids, as.vector=TRUE )
  transcript.to.probeset( ids, as.vector=TRUE )
  transcript.to.protein( ids, as.vector=TRUE )
  transcript.to.synonym( ids, as.vector=TRUE )
}
\arguments{
  \item{as.vector}{ If \code{TRUE} returns a vector of database identifiers. If \code{FALSE} returns a \code{link{RangedData}} object containing detailed annotation. }
  \item{ids}{ Database identifiers to map from. Can be either a vector of database indentifiers, or a \code{\link{RangedData}} object.}
  \item{probes.min}{ How many probes need to match before the probeset is returned. }
  \item{rm.unreliable}{ If \code{TRUE}, the input probeset list is filtered, and all unreliable probesets are removed. }
}
\details{
  In most cases, these functions should be self-explantory. However, by default, the mappings involving probes and probesets 
  do some filtering of the data. This means that probesets which have one or more probes that don't match to the genome, or which 
  match to multiple loci, are removed (see \code{\link{unreliable}} for more details).
}
\value{
  Results in an \code{\link{RangedData}} object, one \'row\' per feature, containing detailed annotations, or a \code{vector}, as defined by \code{as.vector}.

}
\seealso{
  \code{\link{xmapcore.details}}\cr
  \code{\link{xmapcore.all}}\cr
  \code{\link{xmapcore.range}}\cr
  \code{\link{xmapcore.utils}}\cr
  \code{\link{xmapcore.filters}}\cr
  \code{link{RangedData}}
}
\author{
  Tim Yates
}
\examples{
  if(interactive()) {
    xmap.connect()
    gene.to.exon(symbol.to.gene("TP53"))
  } 
}

==> xmapcore_1.12.0.tar.gz: xmapcore/man/xmapcore.to.Rd <==
\name{xmapcore.to}
\alias{xmapcore.to}
\alias{array.to.probeset}
\alias{domain.to.gene}
\alias{domain.to.probeset}
\alias{domain.to.protein}
\alias{domain.to.transcript}
\alias{est_exon.to.est_gene}
\alias{est_exon.to.est_transcript}
\alias{est_exon.to.probeset}
\alias{est_gene.to.est_exon}
\alias{est_gene.to.est_transcript}
\alias{est_gene.to.probeset}
\alias{est_transcript.to.est_exon}
\alias{est_transcript.to.est_gene}
\alias{est_transcript.to.probeset}
\alias{exon.to.gene}
\alias{exon.to.probeset}
\alias{exon.to.transcript}
\alias{gene.to.domain}
\alias{gene.to.exon}
\alias{gene.to.exon_probeset}
\alias{gene.to.exon.probeset.expr}
\alias{gene.to.probeset}
\alias{gene.to.protein}
\alias{gene.to.symbol}
\alias{gene.to.synonym}
\alias{gene.to.transcript}
\alias{prediction_transcript.to.prediction_exon}
\alias{prediction_transcript.to.probeset}
\alias{probe.to.hit}
\alias{probe.to.probeset}
\alias{probeset.to.cdnatranscript}
\alias{probeset.to.domain}
\alias{probeset.to.est_exon}
\alias{probeset.to.est_gene}
\alias{probeset.to.est_transcript}
\alias{probeset.to.exon}
\alias{probeset.to.gene}
\alias{probeset.to.hit}
\alias{probeset.to.prediction_transcript}
\alias{probeset.to.probe}
\alias{probeset.to.protein}
\alias{probeset.to.transcript}
\alias{protein.to.domain}
\alias{protein.to.gene}
\alias{protein.to.probeset}
\alias{protein.to.transcript}
\alias{symbol.to.est_gene}
\alias{symbol.to.est_transcript}
\alias{symbol.to.gene}
\alias{symbol.to.transcript}
\alias{synonym.to.est_gene}
\alias{synonym.to.est_transcript}
\alias{synonym.to.gene}
\alias{synonym.to.transcript}
\alias{transcript.to.cdnaprobeset}
\alias{transcript.to.domain}
\alias{transcript.to.exon}
\alias{transcript.to.exon_probeset}
\alias{transcript.to.gene}
\alias{transcript.to.probeset}
\alias{transcript.to.protein}
\alias{transcript.to.synonym}
\alias{transcript.to.translatedprobes}
\title{
  xmapcore \'to\' functions
}
\description{
  Map between the different levels of annotation in X:Map. For example, given a vector of gene identifiers, \code{gene.to.exon} 
  will return the exons in those genes.
}
\usage{
  array.to.probeset( ids, as.vector=TRUE )
  domain.to.gene( ids, as.vector=TRUE )
  domain.to.probeset( ids, as.vector=TRUE )
  domain.to.protein( ids, as.vector=TRUE )
  domain.to.transcript( ids, as.vector=TRUE )
  est_exon.to.est_gene( ids, as.vector=TRUE )
  est_exon.to.est_transcript( ids, as.vector=TRUE )
  est_exon.to.probeset( ids, as.vector=TRUE )
  est_gene.to.est_exon( ids, as.vector=TRUE )
  est_gene.to.est_transcript( ids, as.vector=TRUE )
  est_gene.to.probeset( ids, as.vector=TRUE )
  est_transcript.to.est_exon( ids, as.vector=TRUE )
  est_transcript.to.est_gene( ids, as.vector=TRUE )
  est_transcript.to.probeset( ids, as.vector=TRUE )
  exon.to.gene( ids, as.vector=TRUE )
  exon.to.probeset( ids, as.vector=TRUE )
  exon.to.transcript( ids, as.vector=TRUE )
  gene.to.domain( ids, as.vector=TRUE )
  gene.to.exon( ids, as.vector=TRUE )
  gene.to.exon_probeset( ids, probes.min=4 )
  gene.to.exon.probeset.expr( x, ids, probes.min=4 )
  gene.to.probeset( ids, as.vector=TRUE )
  gene.to.protein( ids, as.vector=TRUE )
  gene.to.symbol( ids )
  gene.to.synonym( ids, as.vector=TRUE )
  gene.to.transcript( ids, as.vector=TRUE )
  prediction_transcript.to.prediction_exon( ids )
  prediction_transcript.to.probeset( ids, as.vector=TRUE )
  probe.to.hit( ids )
  probe.to.probeset( ids, as.vector=TRUE )
  probeset.to.cdnatranscript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.domain( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.est_exon( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.est_gene( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.est_transcript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.exon( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.gene( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.hit( ids, rm.unreliable=TRUE )
  probeset.to.prediction_transcript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.probe( ids, as.vector=TRUE )
  probeset.to.protein( ids, as.vector=TRUE, rm.unreliable=TRUE )
  probeset.to.transcript( ids, as.vector=TRUE, rm.unreliable=TRUE )
  protein.to.domain( ids, as.vector=TRUE )
  protein.to.gene( ids, as.vector=TRUE )
  protein.to.probeset( ids, as.vector=TRUE )
  protein.to.transcript( ids, as.vector=TRUE )
  symbol.to.est_gene( ids, as.vector=TRUE )
  symbol.to.est_transcript( ids, as.vector=TRUE )
  symbol.to.gene( ids, as.vector=TRUE )
  symbol.to.transcript( ids, as.vector=TRUE )
  synonym.to.est_gene( ids, as.vector=TRUE )
  synonym.to.est_transcript( ids, as.vector=TRUE )
  synonym.to.gene( ids, as.vector=TRUE )
  synonym.to.transcript( ids, as.vector=TRUE )
  transcript.to.cdnaprobeset( ids, as.vector=TRUE )
  transcript.to.domain( ids, as.vector=TRUE )
  transcript.to.exon( ids, as.vector=TRUE )
  transcript.to.exon_probeset( ids, probes.min=4 )
  transcript.to.gene( ids, as.vector=TRUE )
  transcript.to.probeset( ids, as.vector=TRUE )
  transcript.to.protein( ids, as.vector=TRUE )
  transcript.to.synonym( ids, as.vector=TRUE )
  transcript.to.translatedprobes( ids )
}
\arguments{
  \item{as.vector}{ If \code{TRUE} returns a vector of database identifiers. If \code{FALSE}
                    returns a \code{link{RangedData}} object containing detailed annotation. }
  \item{ids}{ Database identifiers to map from. Can be either a vector of database
              identifiers, or a \code{\link{RangedData}} object.}
  \item{probes.min}{ How many probes need to match before the probeset is returned. }
  \item{rm.unreliable}{ If \code{TRUE}, the input probeset list is filtered, and all
                        unreliable probesets are removed. }
  \item{x}{ An \code{\link[Biobase:class.ExpressionSet]{ExpressionSet}} object or a
            \code{matrix} containing expression data. If the latter, then the rownames
            must specify the exon array probeset names. } 
}
\details{
  In most cases, these functions should be self-explantory. However, by default, the mappings involving probes and probesets 
  do some filtering of the data. This means that probesets which have one or more probes that don't match to the genome, or which 
  match to multiple loci, are removed (see \code{\link{unreliable}} for more details).

  The function \code{transcript.to.translatedprobes} always returns a \code{RangedData} object containing each probe that hits the specified translated transcripts and the start and end locations of that hit relative to the start of those transcripts.
}
\value{
  Results in an \code{\link{RangedData}} object, one \'row\' per feature, containing detailed annotations, or a \code{vector}, as defined by \code{as.vector}.

}
\seealso{
  \code{\link{xmapcore.details}}\cr
  \code{\link{xmapcore.all}}\cr
  \code{\link{xmapcore.range}}\cr
  \code{\link{xmapcore.utils}}\cr
  \code{\link{xmapcore.filters}}\cr
  \code{link{RangedData}}
}
\author{
  Tim Yates
}
\examples{
  if(interactive()) {
    xmap.connect()
    gene.to.exon(symbol.to.gene("TP53"))
  } 
}
